proc start_step { step } {
  set stopFile ".stop.rst"
  if {[file isfile .stop.rst]} {
    puts ""
    puts "*** Halting run - EA reset detected ***"
    puts ""
    puts ""
    return -code error
  }
  set beginFile ".$step.begin.rst"
  set platform "$::tcl_platform(platform)"
  set user "$::tcl_platform(user)"
  set pid [pid]
  set host ""
  if { [string equal $platform unix] } {
    if { [info exist ::env(HOSTNAME)] } {
      set host $::env(HOSTNAME)
    }
  } else {
    if { [info exist ::env(COMPUTERNAME)] } {
      set host $::env(COMPUTERNAME)
    }
  }
  set ch [open $beginFile w]
  puts $ch "<?xml version=\"1.0\"?>"
  puts $ch "<ProcessHandle Version=\"1\" Minor=\"0\">"
  puts $ch "    <Process Command=\".planAhead.\" Owner=\"$user\" Host=\"$host\" Pid=\"$pid\">"
  puts $ch "    </Process>"
  puts $ch "</ProcessHandle>"
  close $ch
}

proc end_step { step } {
  set endFile ".$step.end.rst"
  set ch [open $endFile w]
  close $ch
}

proc step_failed { step } {
  set endFile ".$step.error.rst"
  set ch [open $endFile w]
  close $ch
}

set_msg_config -id {HDL 9-1061} -limit 100000
set_msg_config -id {HDL 9-1654} -limit 100000

start_step init_design
set rc [catch {
  create_msg_db init_design.pb
  debug::add_scope template.lib 1
  set_property design_mode GateLvl [current_fileset]
  set_property webtalk.parent_dir C:/Work/Vivado/15.1/ARTY_xadc/ARTY_xadc.cache/wt [current_project]
  set_property parent.project_path C:/Work/Vivado/15.1/ARTY_xadc/ARTY_xadc.xpr [current_project]
  set_property ip_repo_paths c:/Work/Vivado/15.1/ARTY_xadc/ARTY_xadc.cache/ip [current_project]
  set_property ip_output_repo c:/Work/Vivado/15.1/ARTY_xadc/ARTY_xadc.cache/ip [current_project]
  add_files -quiet C:/Work/Vivado/15.1/ARTY_xadc/ARTY_xadc.runs/synth_1/XADCdemo.dcp
  add_files -quiet C:/Work/Vivado/15.1/ARTY_xadc/ARTY_xadc.runs/xadc_wiz_0_synth_1/xadc_wiz_0.dcp
  set_property netlist_only true [get_files C:/Work/Vivado/15.1/ARTY_xadc/ARTY_xadc.runs/xadc_wiz_0_synth_1/xadc_wiz_0.dcp]
  read_xdc -mode out_of_context -ref xadc_wiz_0 -cells inst c:/Work/Vivado/15.1/ARTY_xadc/ARTY_xadc.srcs/sources_1/ip/xadc_wiz_0_1/xadc_wiz_0_ooc.xdc
  set_property processing_order EARLY [get_files c:/Work/Vivado/15.1/ARTY_xadc/ARTY_xadc.srcs/sources_1/ip/xadc_wiz_0_1/xadc_wiz_0_ooc.xdc]
  read_xdc -ref xadc_wiz_0 -cells inst c:/Work/Vivado/15.1/ARTY_xadc/ARTY_xadc.srcs/sources_1/ip/xadc_wiz_0_1/xadc_wiz_0.xdc
  set_property processing_order EARLY [get_files c:/Work/Vivado/15.1/ARTY_xadc/ARTY_xadc.srcs/sources_1/ip/xadc_wiz_0_1/xadc_wiz_0.xdc]
  read_xdc C:/Work/Vivado/15.1/ARTY_xadc/ARTY_xadc.srcs/constrs_1/imports/XDC/Arty_Master.xdc
  link_design -top XADCdemo -part xc7a35tcsg324-1
  close_msg_db -file init_design.pb
} RESULT]
if {$rc} {
  step_failed init_design
  return -code error $RESULT
} else {
  end_step init_design
}

start_step opt_design
set rc [catch {
  create_msg_db opt_design.pb
  catch {write_debug_probes -quiet -force debug_nets}
  opt_design 
  write_checkpoint -force XADCdemo_opt.dcp
  catch {report_drc -file XADCdemo_drc_opted.rpt}
  close_msg_db -file opt_design.pb
} RESULT]
if {$rc} {
  step_failed opt_design
  return -code error $RESULT
} else {
  end_step opt_design
}

start_step place_design
set rc [catch {
  create_msg_db place_design.pb
  catch {write_hwdef -file XADCdemo.hwdef}
  place_design 
  write_checkpoint -force XADCdemo_placed.dcp
  catch { report_io -file XADCdemo_io_placed.rpt }
  catch { report_utilization -file XADCdemo_utilization_placed.rpt -pb XADCdemo_utilization_placed.pb }
  catch { report_control_sets -verbose -file XADCdemo_control_sets_placed.rpt }
  close_msg_db -file place_design.pb
} RESULT]
if {$rc} {
  step_failed place_design
  return -code error $RESULT
} else {
  end_step place_design
}

start_step route_design
set rc [catch {
  create_msg_db route_design.pb
  route_design 
  write_checkpoint -force XADCdemo_routed.dcp
  catch { report_drc -file XADCdemo_drc_routed.rpt -pb XADCdemo_drc_routed.pb }
  catch { report_timing_summary -warn_on_violation -max_paths 10 -file XADCdemo_timing_summary_routed.rpt -rpx XADCdemo_timing_summary_routed.rpx }
  catch { report_power -file XADCdemo_power_routed.rpt -pb XADCdemo_power_summary_routed.pb }
  catch { report_route_status -file XADCdemo_route_status.rpt -pb XADCdemo_route_status.pb }
  catch { report_clock_utilization -file XADCdemo_clock_utilization_routed.rpt }
  close_msg_db -file route_design.pb
} RESULT]
if {$rc} {
  step_failed route_design
  return -code error $RESULT
} else {
  end_step route_design
}

start_step write_bitstream
set rc [catch {
  create_msg_db write_bitstream.pb
  write_bitstream -force XADCdemo.bit 
  catch { write_sysdef -hwdef XADCdemo.hwdef -bitfile XADCdemo.bit -meminfo XADCdemo.mmi -ltxfile debug_nets.ltx -file XADCdemo.sysdef }
  close_msg_db -file write_bitstream.pb
} RESULT]
if {$rc} {
  step_failed write_bitstream
  return -code error $RESULT
} else {
  end_step write_bitstream
}

